@@ -104,7 +104,7 @@ class EquivariantAttention(nn.Module):
         b, n, d, h, fourier_features, device = *feats.shape, self.heads, self.fourier_features, feats.device
 
         rel_coors = rearrange(coors, 'b i d -> b i () d') - rearrange(coors, 'b j d -> b () j d')
-        rel_dist = rel_coors.norm(dim = -1, keepdim = True)
+        rel_dist = (rel_coors ** 2).sum(dim = -1, keepdim = True)
 
         if fourier_features > 0:
             rel_dist = fourier_encode_dist(rel_dist, num_encodings = fourier_features)
